@@ -6,7 +6,9 @@ import sys
 from pathlib import Path
 from typing import Optional
 
+from chia.cmds.passphrase_funcs import get_current_passphrase
 from chia.daemon.client import DaemonProxy, connect_to_daemon_and_validate
+from chia.util.keychain import Keychain, KeyringMaxUnlockAttempts
 from chia.util.service_groups import services_for_groups
 
 
@@ -14,7 +16,7 @@ def launch_start_daemon(root_path: Path) -> subprocess.Popen:
     os.environ["CHIA_ROOT"] = str(root_path)
     # TODO: use startupinfo=subprocess.DETACHED_PROCESS on windows
     chia = sys.argv[0]
-    process = subprocess.Popen(f"{chia} run_daemon".split(), stdout=subprocess.PIPE)
+    process = subprocess.Popen(f"{chia} run_daemon --wait-for-unlock".split(), stdout=subprocess.PIPE)
     return process
 
 
@@ -31,12 +33,27 @@ async def create_start_daemon_connection(root_path: Path) -> Optional[DaemonProx
         # it prints "daemon: listening"
         connection = await connect_to_daemon_and_validate(root_path)
     if connection:
+        passphrase = None
+        if await connection.is_keyring_locked():
+            passphrase = Keychain.get_cached_master_passphrase()
+            if not Keychain.master_passphrase_is_valid(passphrase):
+                passphrase = get_current_passphrase()
+
+        if passphrase:
+            print("Unlocking daemon keyring")
+            await connection.unlock_keyring(passphrase)
+
         return connection
     return None
 
 
 async def async_start(root_path: Path, group: str, restart: bool) -> None:
-    daemon = await create_start_daemon_connection(root_path)
+    try:
+        daemon = await create_start_daemon_connection(root_path)
+    except KeyringMaxUnlockAttempts:
+        print("Failed to unlock keyring")
+        return None
+
     if daemon is None:
         print("Failed to create the chia daemon")
         return None
