@@ -174,8 +174,10 @@ class RateLimiter:
                 new_non_tx_count = self.non_tx_message_counts + 1
                 new_non_tx_size = self.non_tx_cumulative_size + len(message.data)
                 if new_non_tx_count > NON_TX_FREQ * proportion_of_limit:
+                    log.debug(f"Rate limit: {new_non_tx_count} > {NON_TX_FREQ} * {proportion_of_limit}")
                     return False
                 if new_non_tx_size > NON_TX_MAX_TOTAL_SIZE * proportion_of_limit:
+                    log.debug(f"Rate limit: {new_non_tx_size} > {NON_TX_MAX_TOTAL_SIZE} * {proportion_of_limit}")
                     return False
             else:
                 log.warning(f"Message type {message_type} not found in rate limits")
@@ -185,10 +187,13 @@ class RateLimiter:
             assert limits.max_total_size is not None
 
             if new_message_counts > limits.frequency * proportion_of_limit:
+                log.debug(f"Rate limit: {new_message_counts} > {limits.frequency} * {proportion_of_limit}")
                 return False
             if len(message.data) > limits.max_size:
+                log.debug(f"Rate limit: {len(message.data)} > {limits.max_size}")
                 return False
             if new_cumulative_size > limits.max_total_size * proportion_of_limit:
+                log.debug(f"Rate limit: {new_cumulative_size} > {limits.max_total_size} * {proportion_of_limit}")
                 return False
 
             ret = True
