@@ -235,7 +235,7 @@ class WalletTransactionStore:
         await self.add_transaction_record(tx, False)
         return True
 
-    async def tx_reorged(self, record: TransactionRecord):
+    async def tx_reorged(self, record: TransactionRecord, in_transaction: bool):
         """
         Updates transaction sent count to 0 and resets confirmation data
         """
@@ -257,7 +257,7 @@ class WalletTransactionStore:
             name=record.name,
             memos=record.memos,
         )
-        await self.add_transaction_record(tx, False)
+        await self.add_transaction_record(tx, in_transaction=in_transaction)
 
     async def get_transaction_record(self, tx_id: bytes32) -> Optional[TransactionRecord]:
         """
