@@ -5,7 +5,6 @@ import time
 from typing import List
 
 import pytest
-import pytest_asyncio
 
 from chia.full_node.weight_proof import _validate_sub_epoch_summaries
 from chia.protocols import full_node_protocol
@@ -15,42 +14,16 @@ from chia.types.peer_info import PeerInfo
 from chia.util.hash import std_hash
 from chia.util.ints import uint16
 from tests.core.node_height import node_height_exactly, node_height_between
-from tests.setup_nodes import bt, self_hostname, setup_n_nodes, setup_two_nodes, test_constants
+from tests.setup_nodes import test_constants
 from tests.time_out_assert import time_out_assert
 
 
-@pytest.fixture(scope="session")
-def event_loop():
-    loop = asyncio.get_event_loop()
-    yield loop
-
-
 log = logging.getLogger(__name__)
 
 
 class TestFullSync:
-    @pytest_asyncio.fixture(scope="function")
-    async def two_nodes(self, db_version):
-        async for _ in setup_two_nodes(test_constants, db_version=db_version):
-            yield _
-
-    @pytest_asyncio.fixture(scope="function")
-    async def three_nodes(self, db_version):
-        async for _ in setup_n_nodes(test_constants, 3, db_version=db_version):
-            yield _
-
-    @pytest_asyncio.fixture(scope="function")
-    async def four_nodes(self, db_version):
-        async for _ in setup_n_nodes(test_constants, 4, db_version=db_version):
-            yield _
-
-    @pytest_asyncio.fixture(scope="function")
-    async def five_nodes(self, db_version):
-        async for _ in setup_n_nodes(test_constants, 5, db_version=db_version):
-            yield _
-
     @pytest.mark.asyncio
-    async def test_long_sync_from_zero(self, five_nodes, default_400_blocks):
+    async def test_long_sync_from_zero(self, five_nodes, default_400_blocks, bt, self_hostname):
         # Must be larger than "sync_block_behind_threshold" in the config
         num_blocks = len(default_400_blocks)
         blocks: List[FullBlock] = default_400_blocks
@@ -138,7 +111,9 @@ class TestFullSync:
         await time_out_assert(timeout_seconds, node_height_exactly, True, full_node_1, 409)
 
     @pytest.mark.asyncio
-    async def test_sync_from_fork_point_and_weight_proof(self, three_nodes, default_1000_blocks, default_400_blocks):
+    async def test_sync_from_fork_point_and_weight_proof(
+        self, three_nodes, default_1000_blocks, default_400_blocks, self_hostname
+    ):
         start = time.time()
         # Must be larger than "sync_block_behind_threshold" in the config
         num_blocks_initial = len(default_1000_blocks) - 50
@@ -209,7 +184,7 @@ class TestFullSync:
         await time_out_assert(180, node_height_exactly, True, full_node_2, 999)
 
     @pytest.mark.asyncio
-    async def test_batch_sync(self, two_nodes):
+    async def test_batch_sync(self, two_nodes, bt, self_hostname):
         # Must be below "sync_block_behind_threshold" in the config
         num_blocks = 20
         num_blocks_2 = 9
@@ -232,7 +207,7 @@ class TestFullSync:
         await time_out_assert(60, node_height_exactly, True, full_node_2, num_blocks - 1)
 
     @pytest.mark.asyncio
-    async def test_backtrack_sync_1(self, two_nodes):
+    async def test_backtrack_sync_1(self, two_nodes, bt, self_hostname):
         blocks = bt.get_consecutive_blocks(1, skip_slots=1)
         blocks = bt.get_consecutive_blocks(1, blocks, skip_slots=0)
         blocks = bt.get_consecutive_blocks(1, blocks, skip_slots=0)
@@ -249,7 +224,7 @@ class TestFullSync:
         await time_out_assert(60, node_height_exactly, True, full_node_2, 2)
 
     @pytest.mark.asyncio
-    async def test_backtrack_sync_2(self, two_nodes):
+    async def test_backtrack_sync_2(self, two_nodes, bt, self_hostname):
         blocks = bt.get_consecutive_blocks(1, skip_slots=3)
         blocks = bt.get_consecutive_blocks(8, blocks, skip_slots=0)
         full_node_1, full_node_2, server_1, server_2 = two_nodes
@@ -265,7 +240,7 @@ class TestFullSync:
         await time_out_assert(60, node_height_exactly, True, full_node_2, 8)
 
     @pytest.mark.asyncio
-    async def test_close_height_but_big_reorg(self, three_nodes):
+    async def test_close_height_but_big_reorg(self, three_nodes, bt, self_hostname):
         blocks_a = bt.get_consecutive_blocks(50)
         blocks_b = bt.get_consecutive_blocks(51, seed=b"B")
         blocks_c = bt.get_consecutive_blocks(90, seed=b"C")
@@ -303,7 +278,9 @@ class TestFullSync:
         await time_out_assert(60, node_height_exactly, True, full_node_3, 89)
 
     @pytest.mark.asyncio
-    async def test_sync_bad_peak_while_synced(self, three_nodes, default_1000_blocks, default_10000_blocks):
+    async def test_sync_bad_peak_while_synced(
+        self, three_nodes, default_1000_blocks, default_10000_blocks, self_hostname
+    ):
         # Must be larger than "sync_block_behind_threshold" in the config
         num_blocks_initial = len(default_1000_blocks) - 250
         blocks_750 = default_1000_blocks[:num_blocks_initial]
@@ -347,7 +324,7 @@ class TestFullSync:
         assert node_height_exactly(full_node_2, 999)
 
     @pytest.mark.asyncio
-    async def test_block_ses_mismatch(self, two_nodes, default_1000_blocks):
+    async def test_block_ses_mismatch(self, two_nodes, default_1000_blocks, self_hostname):
         full_node_1, full_node_2, server_1, server_2 = two_nodes
         blocks = default_1000_blocks
 
