@@ -13,7 +13,7 @@ from chia.util.ints import uint16
 from chia.wallet.transaction_record import TransactionRecord
 from chia.wallet.wallet_node import WalletNode
 from tests.connection_utils import connect_and_get_peer
-from tests.setup_nodes import bt, self_hostname, setup_simulators_and_wallets
+from tests.setup_nodes import setup_simulators_and_wallets
 from tests.time_out_assert import time_out_assert
 
 
@@ -35,21 +35,16 @@ async def wallet_balance_at_least(wallet_node: WalletNode, balance):
 log = logging.getLogger(__name__)
 
 
-@pytest.fixture(scope="session")
-def event_loop():
-    loop = asyncio.get_event_loop()
-    yield loop
+@pytest_asyncio.fixture(scope="module")
+async def wallet_nodes(bt):
+    key_seed = bt.farmer_master_sk_entropy
+    async for _ in setup_simulators_and_wallets(2, 1, {}, key_seed=key_seed):
+        yield _
 
 
 class TestMempoolPerformance:
-    @pytest_asyncio.fixture(scope="module")
-    async def wallet_nodes(self):
-        key_seed = bt.farmer_master_sk_entropy
-        async for _ in setup_simulators_and_wallets(2, 1, {}, key_seed=key_seed):
-            yield _
-
     @pytest.mark.asyncio
-    async def test_mempool_update_performance(self, wallet_nodes, default_400_blocks):
+    async def test_mempool_update_performance(self, bt, wallet_nodes, default_400_blocks, self_hostname):
         blocks = default_400_blocks
         full_nodes, wallets = wallet_nodes
         wallet_node = wallets[0][0]
@@ -72,7 +67,7 @@ class TestMempoolPerformance:
 
         big_transaction: TransactionRecord = await wallet.generate_signed_transaction(send_amount, ph, fee_amount)
 
-        peer = await connect_and_get_peer(server_1, server_2)
+        peer = await connect_and_get_peer(server_1, server_2, self_hostname)
         await full_node_api_1.respond_transaction(
             full_node_protocol.RespondTransaction(big_transaction.spend_bundle), peer, test=True
         )
