@@ -1,8 +1,6 @@
 import pytest
-import pytest_asyncio
 import aiosqlite
 import random
-import asyncio
 from pathlib import Path
 from typing import List, Tuple
 
@@ -27,12 +25,6 @@ def rand_bytes(num) -> bytes:
     return bytes(ret)
 
 
-@pytest_asyncio.fixture(scope="session")
-def event_loop():
-    loop = asyncio.get_event_loop()
-    yield loop
-
-
 class TestDbUpgrade:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("with_hints", [True, False])
