@@ -9,13 +9,14 @@ from tests.util.keyring import using_temp_file_keyring, using_temp_file_keyring_
 log = logging.getLogger(__name__)
 
 
-class TestKeyringWrapper:
-    @pytest.fixture(autouse=True, scope="function")
-    def setup_keyring_wrapper(self):
-        yield
-        KeyringWrapper.cleanup_shared_instance()
-        assert KeyringWrapper.get_shared_instance(create_if_necessary=False) is None
+@pytest.fixture(autouse=True, scope="function")
+def setup_keyring_wrapper():
+    yield
+    KeyringWrapper.cleanup_shared_instance()
+    assert KeyringWrapper.get_shared_instance(create_if_necessary=False) is None
 
+
+class TestKeyringWrapper:
     def test_shared_instance(self):
         """
         Using KeyringWrapper's get_shared_instance() method should return the same
